/*
 * file CqHit.java
 *
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM 
 *
 * com.ibm.rational.wvcm.stp.cq.CqHit
 *
 * (C) Copyright IBM Corporation 2008, 2014.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */

package com.ibm.rational.wvcm.stp.cq;

import java.util.List;

import javax.wvcm.PropertyNameList;

import com.ibm.rational.wvcm.stp.StpLocation;

/**
 * Information about one record matching by a full-text search query.
 */
public interface CqHit
{
    /**
     * @return The score or rank (from 1 to 100) of this hit compared to the
     *         other hits of the result set. Its common to have one or more
     *         hits with the same score.
     */
    int getScore();

    /**
     * @return The value of the USER_FRIENDLY_LOCATION property of the hit
     *         resource.
     */
    StpLocation getUserFriendlyLocation();

    /**
     * @return The value of the STABLE_LOCATION property of the hit
     *         resource.
     */
    StpLocation getStableLocation();

    /**
     * @return <b>true</b> if the version of the resource that generated this
     *         hit in the indexed content of the database is different from the
     *         version that currently exists in the database. Use this
     *         information to let the user know that this hit item may change
     *         when indexing catches up with the database. For example, its
     *         possible this hit item will not show up as a hit for the same
     *         search when rerun.
     */
    boolean notCurrent();

    /**
     * @return The version of the hit resource in the ClearQuest database. 
     */
    long getVersion();

    /**
     * @return The version of the hit resource whose content has been indexed.
     *         If the value you get back from this call and from getVersion()
     *         are different, the indexing has not yet caught-up with the
     *         updates in the database.
     * 
     */
    long getIndexedVersion();

    /**
     * @return A PropertyNameList containing a PropertyName for each property of
     *         the resource whose value is reported in this hit item. This list
     *         is determined by the database administrator and cannot be changed
     *         by any method in this API. The ordering of this list matches the
     *         ordering of the values returned by getPropertyValues().
     */
    PropertyNameList getPropertyNames();

    /**
     * @return A List<String> containing a value for each property of the
     *         resource reported in this hit. The number and ordering of these
     *         values matches the number and ordering of the PropertyNames
     *         returned by getPropertyNames().
     */
    List<String> getPropertyValues();
    
    /**
     * @return A String of displayName for each record in this hit.
     *         The displayName is returned by getDisplayName().        
     */
    String getDisplayName();

}
